import { EventEmitter } from '@angular/core';
import { Observable, Subject } from 'rxjs';
import { SkyFlyoutBeforeCloseHandler } from './types/flyout-before-close-handler';
import { SkyFlyoutCloseArgs } from './types/flyout-close-args';
import { SkyFlyoutMessage } from './types/flyout-message';
/**
 * Represents a single displayed flyout.
 */
export declare class SkyFlyoutInstance<T> {
    #private;
    /**
     * An event that the flyout instance emits when it is about to close.
     * If a subscription exists for this event,
     * the flyout does not close until the subscriber calls the handler's `closeModal` method.
     */
    get beforeClose(): Observable<SkyFlyoutBeforeCloseHandler>;
    /**
     * An event that the flyout instance emits when it closes.
     */
    closed: EventEmitter<void>;
    /**
     * The instance of the component to display in the flyout.
     */
    componentInstance: T;
    /**
     * Used to communicate with the host component.
     * @internal
     */
    get hostController(): Subject<SkyFlyoutMessage>;
    /**
     * A `boolean` value that returns `true` if the flyout is open.
     * @default true
     */
    isOpen: boolean;
    /**
     * An event that the flyout instance emits when users click the next iterator button.
     */
    get iteratorNextButtonClick(): EventEmitter<void>;
    /**
     * An event that the flyout instance emits when users click the previous iterator button.
     */
    get iteratorPreviousButtonClick(): EventEmitter<void>;
    /**
     * Disables the next iterator button.
     * @default false
     */
    set iteratorNextButtonDisabled(newValue: boolean);
    get iteratorNextButtonDisabled(): boolean;
    /**
     * Disables the previous iterator button.
     * @default false
     */
    set iteratorPreviousButtonDisabled(newValue: boolean);
    get iteratorPreviousButtonDisabled(): boolean;
    constructor(componentInstance?: T);
    /**
     * Closes the flyout instance and emits its `closed` event.
     * @param args Arguments used when closing the flyout.
     */
    close(args?: SkyFlyoutCloseArgs): void;
}
