import { NgZone, OnDestroy, Type } from '@angular/core';
import { Router } from '@angular/router';
import { SkyAppWindowRef, SkyCoreAdapterService, SkyDynamicComponentLegacyService, SkyDynamicComponentService } from '@skyux/core';
import { SkyFlyoutInstance } from './flyout-instance';
import { SkyFlyoutCloseArgs } from './types/flyout-close-args';
import { SkyFlyoutConfig } from './types/flyout-config';
import * as i0 from "@angular/core";
/**
 * Launches flyouts and provides a common look and feel.
 * This service dynamically generates the flyout component and appends it directly to the
 * document's `body` element. The `SkyFlyoutInstance` class watches for and triggers flyout events.
 */
export declare class SkyFlyoutService implements OnDestroy {
    #private;
    private static host;
    constructor(coreAdapter: SkyCoreAdapterService, windowRef: SkyAppWindowRef, dynamicComponentService: SkyDynamicComponentService, router: Router, ngZone: NgZone);
    ngOnDestroy(): void;
    /**
     * Closes the flyout. This method also removes the flyout's HTML elements from the DOM.
     * @param args Arguments used when closing the flyout.
     */
    close(args?: SkyFlyoutCloseArgs): void;
    /**
     * Opens a flyout and displays the specified component.
     * @param component Specifies the component to render.
     * @param config Specifies the flyout configuration passed to the specified component's constructor.
     */
    open<T>(component: Type<T>, config?: SkyFlyoutConfig): SkyFlyoutInstance<T>;
    static ɵfac: i0.ɵɵFactoryDeclaration<SkyFlyoutService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<SkyFlyoutService>;
}
/**
 * Launches flyouts and provides a common look and feel.
 * This service dynamically generates the flyout component and appends it directly to the
 * document's `body` element. The `SkyFlyoutInstance` class watches for and triggers flyout events.
 * @internal
 * @deprecated Use `SkyFlyoutService` to open a standalone component instead.
 */
export declare class SkyFlyoutLegacyService extends SkyFlyoutService {
    constructor(coreAdapter: SkyCoreAdapterService, windowRef: SkyAppWindowRef, dynamicComponentService: SkyDynamicComponentLegacyService, router: Router, ngZone: NgZone);
    static ɵfac: i0.ɵɵFactoryDeclaration<SkyFlyoutLegacyService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<SkyFlyoutLegacyService>;
}
